@@ -1,8 +1,9 @@
 require_relative 'buffered_shared'
+require 'concurrent/channel/buffer/sliding'
 
 module Concurrent::Channel::Buffer
 
-  RSpec.describe Sliding, edge: true, notravis: true do
+  RSpec.describe Sliding, edge: true do
 
     subject { described_class.new(10) }
 
